@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-gst.c,v 1.160.2.1 2005/04/18 09:03:09 rbultje Exp $
+ * $Id: bacon-video-widget-gst.c,v 1.160.2.2 2005/05/17 21:18:02 rbultje Exp $
  *
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
@@ -977,7 +977,7 @@ got_stream_length (GstElement * play, gint64 length_nanos,
 
   bvw->priv->stream_length = (gint64) length_nanos / GST_MSECOND;
   
-  g_signal_emit (G_OBJECT (bvw), bvw_table_signals[SIGNAL_GOT_METADATA], 0, NULL);
+  //g_signal_emit (G_OBJECT (bvw), bvw_table_signals[SIGNAL_GOT_METADATA], 0, NULL);
 }
 
 static void
