@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.174.2.3 2005/05/22 22:47:35 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.174.2.6 2005/06/18 00:00:43 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -138,6 +138,7 @@ struct BaconVideoWidgetPrivate {
 	Display *display;
 	int screen;
 	GdkWindow *video_window;
+	GdkCursor *cursor;
 
 	/* Visual effects */
 	char *vis_name;
@@ -449,6 +450,9 @@ bacon_video_widget_finalize (GObject *object)
 	if (bvw->priv->xine != NULL) {
 		xine_exit (bvw->priv->xine);
 	}
+	if (bvw->priv->cursor != NULL) {
+		gdk_cursor_unref (bvw->priv->cursor);
+	}
 	g_free (bvw->priv->vis_name);
 	g_object_unref (G_OBJECT (bvw->priv->gc));
 	g_free (bvw->priv->codecs_path);
@@ -460,8 +464,7 @@ bacon_video_widget_finalize (GObject *object)
 	g_async_queue_unref (bvw->priv->queue);
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
-	bvw->priv = NULL;
-	bvw = NULL;
+	g_free (bvw->priv);
 }
 
 static void
@@ -1210,6 +1213,7 @@ bacon_video_widget_idle_signal (BaconVideoWidget *bvw)
 		g_signal_emit (G_OBJECT (bvw),
 				bvw_table_signals[ERROR], 0,
 				data->msg, TRUE, data->fatal);
+		break;
 	default:
 		g_assert_not_reached ();
 	}
@@ -1332,14 +1336,17 @@ xine_event (void *user_data, const xine_event_t *event)
 		spubtn = (xine_spu_button_t *) event->data;
 		if (spubtn->direction)
 		{
-			GdkCursor *cursor;
-			cursor = gdk_cursor_new (GDK_HAND2);
-			gdk_window_set_cursor
-				(bvw->priv->video_window, cursor);
-			gdk_cursor_unref (cursor);
+			if (bvw->priv->cursor == NULL) {
+				bvw->priv->cursor = gdk_cursor_new (GDK_HAND2);
+			}
 		} else {
-			gdk_window_set_cursor(bvw->priv->video_window, NULL);
+			if (bvw->priv->cursor != NULL) {
+				gdk_cursor_unref (bvw->priv->cursor);
+				bvw->priv->cursor = NULL;
+			}
 		}
+		gdk_window_set_cursor (bvw->priv->video_window,
+				bvw->priv->cursor);
 		break;
 	case XINE_EVENT_UI_PLAYBACK_FINISHED:
 		if (bvw->priv->got_redirect != FALSE)
@@ -1908,6 +1915,7 @@ bacon_video_widget_open_with_subtitle (BaconVideoWidget *bvw, const char *mrl,
 		const char *subtitle_uri, GError **error)
 {
 	int err;
+	const char *layer;
 
 	g_return_val_if_fail (mrl != NULL, FALSE);
 	g_return_val_if_fail (BACON_IS_VIDEO_WIDGET (bvw), FALSE);
@@ -1933,7 +1941,9 @@ bacon_video_widget_open_with_subtitle (BaconVideoWidget *bvw, const char *mrl,
 		return FALSE;
 	}
 
-	if (strcmp (xine_get_meta_info (bvw->priv->stream, XINE_META_INFO_SYSTEMLAYER), "MNG") == 0 && bvw->priv->logo_mode == FALSE)
+	layer = xine_get_meta_info (bvw->priv->stream,
+			XINE_META_INFO_SYSTEMLAYER);
+	if ((strcmp (layer, "MNG") == 0 || strcmp (layer, "imagedmx") == 0)&& bvw->priv->logo_mode == FALSE)
 	{
 		bacon_video_widget_close (bvw);
 		g_set_error (error, BVW_ERROR, BVW_ERROR_STILL_IMAGE,
@@ -2455,7 +2465,8 @@ bacon_video_widget_set_show_cursor (BaconVideoWidget *bvw,
 	{
 		eel_gdk_window_set_invisible_cursor (bvw->priv->video_window);
 	} else {
-		gdk_window_set_cursor (bvw->priv->video_window, NULL);
+		gdk_window_set_cursor (bvw->priv->video_window,
+				bvw->priv->cursor);
 	}
 
 	bvw->priv->cursor_shown = show_cursor;
