@@ -30,6 +30,10 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <libgnomevfs/gnome-vfs-mime-info.h>
+
+#include "totem-mozilla-options.h"
 
 #define XP_UNIX 1
 #define MOZ_X11 1
@@ -43,9 +47,11 @@ typedef struct {
 	NPP instance;
 	guint32 window;
 
+	char *src, *href;
 	int width, height;
-	int recv_fd, send_fd;
+	int send_fd;
 	int player_pid;
+	gboolean controller_hidden;
 
 	GByteArray *bytes;
 } TotemPlugin;
@@ -53,7 +59,7 @@ typedef struct {
 static NPNetscapeFuncs mozilla_functions;
 
 /* You don't update, you die! */
-#define MAX_ARGV_LEN 10
+#define MAX_ARGV_LEN 14
 
 static void totem_plugin_fork (TotemPlugin *plugin)
 {
@@ -67,22 +73,36 @@ static void totem_plugin_fork (TotemPlugin *plugin)
 				G_FILE_TEST_EXISTS) != FALSE) {
 		argv[argc++] = g_strdup ("./totem-mozilla-viewer");
 	} else {
-		argv[argc++] = g_strdup (LIBDIR"/totem/totem-mozilla-viewer");
+		argv[argc++] = g_strdup (LIBEXECDIR"/totem-mozilla-viewer");
 	}
 
-	argv[argc++] = "--xid";
+	argv[argc++] = g_strdup (TOTEM_OPTION_XID);
 	argv[argc++] = g_strdup_printf ("%d", plugin->window);
 
 	if (plugin->width) {
-		argv[argc++] = g_strdup ("--width");
+		argv[argc++] = g_strdup (TOTEM_OPTION_WIDTH);
 		argv[argc++] = g_strdup_printf ("%d", plugin->width);
 	}
 
 	if (plugin->height) {
-		argv[argc++] = g_strdup ("--height");
+		argv[argc++] = g_strdup (TOTEM_OPTION_HEIGHT);
 		argv[argc++] = g_strdup_printf ("%d", plugin->height);
 	}
 
+	if (plugin->src) {
+		argv[argc++] = g_strdup (TOTEM_OPTION_URL);
+		argv[argc++] = g_strdup (plugin->src);
+	}
+	
+	if (plugin->href) {
+		argv[argc++] = g_strdup (TOTEM_OPTION_HREF);
+		argv[argc++] = g_strdup (plugin->href);
+	}
+
+	if (plugin->controller_hidden) {
+		argv[argc++] = g_strdup ("--nocontrols");
+	}
+
 	argv[argc++] = g_strdup ("fd://0");
 	argv[argc] = NULL;
 
@@ -97,7 +117,6 @@ static void totem_plugin_fork (TotemPlugin *plugin)
 
 	if (g_spawn_async_with_pipes (NULL, argv, NULL,
 				G_SPAWN_DO_NOT_REAP_CHILD,
-//				| G_SPAWN_STDOUT_TO_DEV_NULL,
 				NULL, NULL, &plugin->player_pid,
 				&plugin->send_fd, NULL, NULL, &err) == FALSE)
 	{
@@ -137,21 +156,48 @@ static NPError totem_plugin_new_instance (NPMIMEType mime_type, NPP instance,
 	printf("mode %d\n",mode);
 	//printf("mime type: %s\n",pluginType);
 	plugin->instance = instance;
+	plugin->send_fd = -1;
 
 	for (i=0; i<argc; i++) {
 		printf ("argv[%d] %s %s\n", i, argn[i], argv[i]);
-		if (strcmp (argn[i],"width") == 0) {
+		if (g_ascii_strcasecmp (argn[i],"width") == 0) {
 			plugin->width = strtol (argv[i], NULL, 0);
 		}
-		if (strcmp (argn[i], "height") == 0) {
+		if (g_ascii_strcasecmp (argn[i], "height") == 0) {
 			plugin->height = strtol (argv[i], NULL, 0);
 		}
-
-		//Handle loop
+		//FIXME we can have some relative paths here as well!
+		if (g_ascii_strcasecmp (argn[i], "src") == 0) {
+			plugin->src = g_strdup (argv[i]);
+		}
+		if (g_ascii_strcasecmp (argn[i], "href") == 0) {
+			plugin->href = g_strdup (argv[i]);
+		}
+		if (g_ascii_strcasecmp (argn[i], "controller") == 0) {
+			if (g_ascii_strcasecmp (argv[i], "false") == 0) {
+				plugin->controller_hidden = TRUE;
+			}
+			//FIXME see http://www.htmlcodetutorial.com/embeddedobjects/_EMBED_CONTROLS.html
+		}
+		if (g_ascii_strcasecmp (argn[i], "hidden") == 0) {
+			//FIXME
+		}
+		if (g_ascii_strcasecmp (argn[i], "autostart") == 0
+				|| g_ascii_strcasecmp (argn[i], "autoplay") == 0) {
+			//FIXME
+		}
+		if (g_ascii_strcasecmp (argn[i], "loop") == 0 ||
+				g_ascii_strcasecmp (argn[i], "playcount") == 0) {
+			//FIXME see http://www.htmlcodetutorial.com/embeddedobjects/_EMBED_LOOP.html
+		}
+		if (g_ascii_strcasecmp (argn[i], "starttime") == 0) {
+			//FIXME see http://www.htmlcodetutorial.com/embeddedobjects/_EMBED_STARTTIME.html
+		}
+		if (g_ascii_strcasecmp (argn[i], "endtime") == 0) {
+			//FIXME see above
+		}
 	}
 
-	//totem_plugin_fork(plugin, 0x32);
-
 	return NPERR_NO_ERROR;
 }
 
@@ -168,11 +214,13 @@ static NPError totem_plugin_destroy_instance (NPP instance, NPSavedData **save)
 	if (plugin == NULL)
 		return NPERR_NO_ERROR;
 
-//	close(plugin->send_fd);
-//	close(plugin->recv_fd);
+	if (plugin->send_fd >= 0)
+		close(plugin->send_fd);
 
-//	kill (plugin->player_pid, SIGKILL);
-//	waitpid (plugin->player_pid, NULL, 0);
+	if (plugin->player_pid) {
+		kill (plugin->player_pid, SIGKILL);
+		waitpid (plugin->player_pid, NULL, 0);
+	}
 
 	mozilla_functions.memfree (instance->pdata);
 	instance->pdata = NULL;
@@ -204,16 +252,12 @@ static NPError totem_plugin_set_window (NPP instance, NPWindow* window)
 			printf ("ack.  window changed!\n");
 		}
 	} else {
-		NPSetWindowCallbackStruct *ws_info;
-
 		DEBUG("about to fork");
 
-		ws_info = window->ws_info;
 		plugin->window = (Window) window->window;
-
 		totem_plugin_fork (plugin);
 
-		//fcntl(plugin->send_fd, F_SETFL, O_NONBLOCK);
+		fcntl(plugin->send_fd, F_SETFL, O_NONBLOCK);
 	}
 
 	DEBUG("leaving plugin_set_window");
@@ -235,8 +279,20 @@ static NPError totem_plugin_new_stream (NPP instance, NPMIMEType type,
 static NPError totem_plugin_destroy_stream (NPP instance, NPStream* stream,
 		NPError reason)
 {
+	TotemPlugin *plugin;
+
 	DEBUG("plugin_destroy_stream");
 
+	if (instance == NULL) {
+		DEBUG("totem_plugin_destroy_stream instance is NULL");
+		return NPERR_NO_ERROR;
+	}
+
+	plugin = (TotemPlugin *) instance->pdata;
+
+	close(plugin->send_fd);
+	plugin->send_fd = -1;
+
 	return NPERR_NO_ERROR;
 }
 
@@ -253,8 +309,10 @@ static int32 totem_plugin_write_ready (NPP instance, NPStream *stream)
 
 	plugin = (TotemPlugin *) instance->pdata;
 
-	return (8*1024);
-//	return 4096;
+	if (plugin->send_fd >0)
+		return (8*1024);
+
+	return 0;
 }
 
 static int32 totem_plugin_write (NPP instance, NPStream *stream, int32 offset,
@@ -276,9 +334,15 @@ static int32 totem_plugin_write (NPP instance, NPStream *stream, int32 offset,
 	if (!plugin->player_pid)
 		return 0;
 
+	if (plugin->send_fd < 0)
+		return 0;
+
+//	g_message ("write %d %p %d", plugin->send_fd, buffer, len);
 	ret = write (plugin->send_fd, buffer, len);
-	if (ret < 0)
+	if (ret < 0) {
+		g_message ("ret %d", ret);
 		ret = 0;
+	}
 
 	return ret;
 }
@@ -326,9 +390,14 @@ totem_plugin_get_value (NPP instance, NPPVariable variable,
 	case NPPVpluginNeedsXEmbed:
 		*((PRBool *)value) = PR_TRUE;
 		break;
+	case NPPVpluginScriptableIID:
+		g_message ("we're not scriptable yet: NPPVpluginScriptableIID");
+		*((PRBool *)value) = PR_FALSE;
+		break;
 	default:
 		g_message ("unhandled variable %d", variable);
 		err = NPERR_INVALID_PARAM;
+		break;
 	}
 
 	return err;
@@ -349,28 +418,44 @@ NP_GetValue(void *future, NPPVariable variable, void *value)
 	return totem_plugin_get_value (NULL, variable, value);
 }
 
+#define NUM_MIME_TYPES 3 //FIXME no realaudio just yet
+static struct {
+	const char *mime_type;
+	const char *extensions;
+	const char *mime_alias;
+} mime_types[] = {
+	{ "video/quicktime", "mov" },
+	{ "application/x-mplayer2", "avi, wma, wmv", "video/x-msvideo" },
+	{ "video/mpeg", "mpg, mpeg, mpe" },
+	{ "audio/x-pn-realaudio-plugin", "rpm", "audio/x-pn-realaudio" }
+};
+
 char *NP_GetMIMEDescription(void)
 {
-	//FIXME i18n
+	GString *list;
+	char *mime_list;
+	guint i;
 
-	return
-		/* http://www.apple.com/trailers/ */
-		"video/quicktime:mov:QuickTime video;"
-		/* http://www.nbc.com/nbc/Late_Night_with_Conan_O'Brien/video/triumph.shtml */
-		"application/x-mplayer2::Window Media Plugin;";
-/*
-    		"application/mpeg:mpg:MPEG video;"
-    		"audio/x-pn-windows-acm:wav:WAV audio;"
-    		"audio/x-wav:wav:WAV audio;"
-    		"audio/x-ogg:ogg:Ogg Vorbis audio;"
-    		"audio/basic:au:basic audio;"
-    		"audio/mpeg:mp1:MPEG audio;"
-    		"audio/mpeg:mp2:MPEG audio;"
-    		"audio/mpeg:mp3:MPEG audio;"
-		"video/mpeg:mpg:MPEG video;"
-		"video/mpeg:vob:MPEG video;"
-		"video/quicktime:mov:QuickTime video;"
-		"video/x-msvideo:avi:AVI video"; */
+	list = g_string_new (NULL);
+
+	for (i = 0; i < NUM_MIME_TYPES; i++) {
+		const char *desc;
+		char *item;
+
+		desc = gnome_vfs_mime_get_description (mime_types[i].mime_type);
+		if (desc == NULL) {
+			desc = gnome_vfs_mime_get_description
+				(mime_types[i].mime_alias);
+		}
+		item = g_strdup_printf ("%s:%s:%s;", mime_types[i].mime_type,
+				mime_types[i].extensions, desc);
+		list = g_string_append (list, item);
+		g_free (item);
+	}
+
+	mime_list = g_string_free (list, FALSE);
+
+	return mime_list;
 }
 
 NPError NP_Initialize (NPNetscapeFuncs * moz_funcs,
