@@ -122,16 +122,25 @@ totem_statusbar_init (TotemStatusbar *statusbar)
   gtk_widget_show (hbox);
 
   statusbar->label = gtk_label_new (_("Stopped"));
-  gtk_misc_set_alignment (GTK_MISC (statusbar->label), 0.0, 0.0);
+  gtk_misc_set_alignment (GTK_MISC (statusbar->label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (hbox), statusbar->label, FALSE, FALSE, 0);
   gtk_widget_show (statusbar->label);
 
+  /* progressbar for network streams */
+  statusbar->progress = gtk_progress_bar_new ();
+  gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (statusbar->progress),
+				    GTK_ORIENTATION_HORIZONTAL);
+  gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (statusbar->progress), 0.);
+  gtk_box_pack_start (GTK_BOX (hbox), statusbar->progress, FALSE, TRUE, 0);
+  gtk_widget_set_size_request (statusbar->progress, 150, 10);
+  gtk_widget_hide (statusbar->progress);
+
   packer = gtk_vseparator_new ();
   gtk_box_pack_start (GTK_BOX (hbox), packer, FALSE, FALSE, 0);
   gtk_widget_show (packer);
 
   statusbar->time_label = gtk_label_new (_("0:00 / 0:00"));
-  gtk_misc_set_alignment (GTK_MISC (statusbar->label), 0.0, 0.0);
+  gtk_misc_set_alignment (GTK_MISC (statusbar->label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (hbox), statusbar->time_label, FALSE, FALSE, 0);
   gtk_widget_show (statusbar->time_label);
 
@@ -152,9 +161,6 @@ totem_statusbar_update_time (TotemStatusbar *statusbar)
 {
   char *time, *length, *label;
 
-  if (statusbar->pushed == 1)
-    return;
-
   time = totem_time_to_string (statusbar->time * 1000);
 
   if (statusbar->length < 0) {
@@ -190,8 +196,10 @@ totem_statusbar_set_time (TotemStatusbar *statusbar, gint time)
 {
   g_return_if_fail (TOTEM_IS_STATUSBAR (statusbar));
 
-  statusbar->time = time;
+  if (statusbar->time == time)
+    return;
 
+  statusbar->time = time;
   totem_statusbar_update_time (statusbar);
 }
 
@@ -202,7 +210,7 @@ totem_statusbar_timeout_pop (TotemStatusbar *statusbar)
   g_free (statusbar->saved_label);
   statusbar->saved_label = NULL;
   statusbar->pushed = 0;
-  totem_statusbar_update_time (statusbar);
+  gtk_widget_hide (statusbar->progress);
 
   return FALSE;
 }
@@ -218,12 +226,6 @@ totem_statusbar_push (TotemStatusbar *statusbar, guint percentage)
     g_source_remove (statusbar->timeout);
   }
 
-  if (percentage == 100)
-  {
-    totem_statusbar_timeout_pop (statusbar);
-    return;
-  }
-
   if (statusbar->saved_label == NULL)
   {
     statusbar->saved_label = g_strdup
@@ -234,8 +236,11 @@ totem_statusbar_push (TotemStatusbar *statusbar, guint percentage)
 
   /* eg: 75 % */
   label = g_strdup_printf (_("%d %%"), percentage);
-  gtk_label_set_text (GTK_LABEL (statusbar->time_label), label);
+  gtk_progress_bar_set_text (GTK_PROGRESS_BAR (statusbar->progress), label);
   g_free (label);
+  gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (statusbar->progress),
+				 percentage / 100.);
+  gtk_widget_show (statusbar->progress);
 
   statusbar->timeout = g_timeout_add (3000,
 		  (GSourceFunc) totem_statusbar_timeout_pop, statusbar);
